# -*- coding: utf-8 -*-
"""
cyipopt: Python wrapper for the Ipopt optimization package, written in Cython.

Copyright (C) 2012-2015 Amit Aides
Copyright (C) 2015-2017 Matthias Kümmerer
Copyright (C) 2017-2021 cyipopt developers

License: EPL 1.0
"""

from __future__ import absolute_import

from ipopt_wrapper import *
from .ipopt_wrapper import *
from .scipy_interface import *
from .version import __version__



import numpy as np
import pytest

import cyipopt


def test_hs071_solve(hs071_initial_guess_fixture, hs071_problem_instance_fixture):
	"""Test hs071 test problem solves to the correct solution."""
	x0 = hs071_initial_guess_fixture
	nlp = hs071_problem_instance_fixture
	x, info = nlp.solve(x0)

	expected_J = 17.01401714021362
	np.testing.assert_almost_equal(info["obj_val"], expected_J)

	expected_x = np.array([1.0, 4.74299964, 3.82114998, 1.37940829])
	np.testing.assert_allclose(x, expected_x)



import sys
import warnings

sys.modules[__name__] = __import__("cyipopt")


def issue_deprecation_warning():
    """Warn user of deprication of 'ipopt' as module name."""
    msg = ("The module has been renamed to 'cyipopt' from 'ipopt'. Please "
           "import using 'import cyipopt' and remove all uses of "
           "'import ipopt' in your code as this will be deprecated in a "
           "future release.")
    warnings.warn(msg, FutureWarning)


issue_deprecation_warning()
